.. _spectral:

Event Weighting and Spectrum Definitions
========================================


Reference/API
-------------


.. automodapi:: pyirf.spectral
    :no-inheritance-diagram:
    :include-all-objects:
